Shelves
=======

A shelf is a container for holding Ingredients. 

Shelves act like dictionaries with keys that are strings and values
that are Ingredients.

Adding ingredients to a Shelf sets the ingredient ``id`` to the key
used in the Shelf.